@@ -4,10 +4,9 @@
 //
 // started November 2000
 // Peter Beerli Seattle 2000
-// $Id: bayes.h,v 1.10 2004/04/19 15:27:11 beerli Exp $
+// $Id: bayes.h 175 2005-12-02 14:51:23Z beerli $
 //
 #include "migration.h"
-#ifdef BAYESUPDATE
 extern boolean acceptBayes (MYREAL newval, MYREAL oldval);
 extern long bayes_update (world_fmt *world);
 extern void bayes_free(world_fmt *world);
@@ -18,7 +17,6 @@ extern void bayes_stat(world_fmt *world);
 extern void bayes_init_histogram(world_fmt * world, option_fmt * options);
 extern void calculate_credibility_interval(world_fmt * world, long locus);
 extern void bayes_reset(world_fmt * world);
-
-#endif /*baysupdate*/
-
+extern void bayes_check_and_fix_param(world_fmt *world, option_fmt *options);
+extern void print_bayes_mdimfileheader(FILE *file, long interval);
 #endif
