@@ -19,7 +19,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
- $Id: broyden.c,v 1.81 2005/01/21 16:48:33 beerli Exp $
+ $Id: broyden.c 175 2005-12-02 14:51:23Z beerli $
 -------------------------------------------------------*/
 /*! \file broyden.c
 Basic routines for maximum likelihood parameter estimation.
@@ -157,7 +157,7 @@ calc_line_new (helper_fmt * helper, MYREAL a, MYREAL b, MYREAL c,
     MYREAL xhigh = c;
     MYREAL xlow = a;
     MYREAL low, high, mid, xmid;
-    MYREAL xguess;
+    MYREAL xguess=0.;
     int panic = 0;
     low = (*fpsi) (xlow, helper);
     high = (*fpsi) (xhigh, helper);
@@ -2243,9 +2243,9 @@ void unset_penalizer_function(boolean inprofiles)
         normal_func_gradient = (MYREAL (*)(MYREAL , MYREAL)) normal_func_gradient_no;
     }
     else
-    {
-        normal_func = (MYREAL (*)(MYREAL *, MYREAL *,  long)) normal_func_ok;
-        normal_func_gradient = (MYREAL (*)(MYREAL, MYREAL)) normal_func_gradient_ok;
+      {   ///debug was originaly OK and not NO
+        normal_func = (MYREAL (*)(MYREAL *, MYREAL *,  long)) normal_func_no;
+        normal_func_gradient = (MYREAL (*)(MYREAL, MYREAL)) normal_func_gradient_no;
     }
 }
 
