@@ -25,7 +25,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: combroyden2.c,v 1.96 2005/01/21 16:48:33 beerli Exp $
+$Id: combroyden2.c 175 2005-12-02 14:51:23Z beerli $
  
 -------------------------------------------------------*/
 
@@ -36,8 +36,8 @@ $Id: combroyden2.c,v 1.96 2005/01/21 16:48:33 beerli Exp $
 #include "world.h"
 #include "integrate.h"
 #ifndef LAGUERRE
-#include "derivatives.h"
-#include "derivatives2.h"
+//#include "derivatives.h"
+//#include "derivatives2.h"
 #endif
 #include "migrate_mpi.h"
 #include "reporter.h"
@@ -165,7 +165,9 @@ void fill_helper (helper_fmt * helper, MYREAL *param, MYREAL *lparam,
                   world_fmt * world, nr_fmt * nr);
 
 /* maximizer routine */
-long maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, long analystype,
+long maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, 
+	       MYREAL **hess,
+	       long analystype,
                long repkind);
 
 void set_both_delta (nr_fmt * nr,
@@ -194,17 +196,13 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
     MYREAL likes = 0.;
     MYREAL *param;
 #ifndef MPI
-    //  long i;
-    //#else
     long repstart, repstop;
 #endif
 
     boolean multilocus;
     nr_fmt *nr;
-#ifdef BAYESUPDATE
     if (world->options->bayes_infer)
         return -1; //when we run in Baysian mode we do not need to maximuze the likelihood
-#endif
     nr = (nr_fmt *) mycalloc (1, sizeof (nr_fmt));
     if (kind == MULTILOCUS)
     {
@@ -250,12 +248,12 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
     {
         if (kind == SINGLELOCUS
                 && world->options->custm2[world->numpop2] == 'c')
-            trials = maximize (&param, world, nr, kind, repkind);
+            trials = maximize (&param, world, nr, dd, kind, repkind);
         else 
             trials = do_profiles (world, nr, &likes, &normd, kind, rep, repkind);
     }
     else
-        trials = maximize (&param, world, nr, kind, repkind);
+        trials = maximize (&param, world, nr, dd, kind, repkind);
 
     if (kind == SINGLELOCUS && world->options->progress)
     {
@@ -979,6 +977,7 @@ long
 do_profiles (world_fmt * world, nr_fmt * nr, MYREAL *likes,
              MYREAL *normd, long kind, long rep, long repkind)
 {
+  MYREAL **hess;
     char *p;
     long z = 0;
     long trials;
@@ -998,7 +997,15 @@ do_profiles (world_fmt * world, nr_fmt * nr, MYREAL *likes,
     nr->profilenum = z;
     if(kind!=SINGLELOCUS)
       world->locus = world->loci;
-    trials = maximize (&world->param0, world, nr, kind, repkind);
+    // use a private copy of the hessian so not to clobber the
+    // version we use to print out the -fisher information
+    z = world->numpop2 + 
+      (world->locus == world->loci ? 
+       world->options->gamma : 0);
+      doublevec2d(&hess,z,z);
+    trials = maximize (&world->param0, world, nr, hess, kind, repkind);
+    free(hess[0]);
+    free(hess);
     return trials;
 }
 
@@ -1285,7 +1292,7 @@ fill_profile_index (nr_fmt * nr)
 // maximizer sceleton
 // analystype = (SINGLELOCUS, MULTILOCUS, PROFILE)
 long
-maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, long analystype,
+maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, MYREAL **hess, long analystype,
           long repkind)
 {
     boolean stop;
@@ -1303,7 +1310,7 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, long analystype,
     long nn;   // keeps track of the full parameter array
     
     MYREAL *param;
-    MYREAL **hess;
+    //    MYREAL **hess;
     MYREAL *delta;
     MYREAL *gama;
     MYREAL *dv = NULL;
@@ -1322,7 +1329,7 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, long analystype,
     helper.boolgamma = world->locus == world->loci ? wopt->gamma : FALSE;
     if (helper.boolgamma)
         param[nnn - 1] = world->options->alphavalue;
-    doublevec2d (&hess, nnn, nnn);
+    //doublevec2d (&hess, nnn, nnn);
     reset_hess (hess, nnn);
     doublevec1d (&delta, nnn);
     doublevec1d (&gama, nnn);
@@ -1459,8 +1466,8 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, long analystype,
                     analystype, repkind);
     memcpy ((*thisparam), expxv, sizeof (MYREAL) * nn);
     free(param);
-    free (hess[0]);
-    free (hess);
+    //free (hess[0]);
+    //free (hess);
     free (delta);
     free (gama);
     free (dv);
