@@ -22,7 +22,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c,v 1.54 2005/01/21 16:48:33 beerli Exp $
+$Id: data.c 175 2005-12-02 14:51:23Z beerli $
  
 -------------------------------------------------------*/
 /*! \file data.c
@@ -308,11 +308,17 @@ init_data_structure3 (data_fmt * data)
         (boolean *) mycalloc (1, sizeof (boolean) * (data->loci + 1));
 }
 
-
-void
-read_header (FILE * infile, data_fmt * data, option_fmt * options)
+///
+/// read the first line of the data file
+/// \param infile datafilename
+/// \param data   data structure that holds all the data
+/// \param options structure that contain all option information
+/// \reval none
+void read_header (FILE * infile, data_fmt * data, option_fmt * options)
 {
     char input[LINESIZE], *p;
+    char title[LINESIZE];
+    strcpy(title,"\0");
     FGETS (input, sizeof (input), infile);
     if ((p = (char *) strpbrk (input, CRLF)) != NULL)
         *p = '\0';
@@ -320,20 +326,26 @@ read_header (FILE * infile, data_fmt * data, option_fmt * options)
     {
     case 'a':
         sscanf (input, "%1s%ld%ld%[^\n]", &options->datatype, &(data->numpop),
-                &(data->loci), options->title);
-        find_delimiter (options->title, &data->dlm);
+                &(data->loci), title);
+        find_delimiter (title, &data->dlm);
+	if(!(title[0]==' ' || title[0] == '\0'))
+	  strcpy(options->title,title);
         break;
     case 'b':
     case 'm':
         sscanf (input, "%1s%ld%ld%1s%[^\n]", &options->datatype,
-                &(data->numpop), &(data->loci), &data->dlm, options->title);
+                &(data->numpop), &(data->loci), &data->dlm, title);
+	if(!(title[0]==' ' || title[0] == '\0'))
+	  strcpy(options->title,title);
         break;
     case 's':
     case 'n':
     case 'u':
     case 'f':
         sscanf (input, "%1s%ld%ld%[^\n]", &options->datatype, &(data->numpop),
-                &(data->loci), options->title);
+                &(data->loci), title);
+	if(!(title[0]==' ' || title[0] == '\0'))
+	  strcpy(options->title,title);
         break;
     case 'g':   /* fall through if a menu change forces to analyze data
                                instead of using the already sampled genealogies */
@@ -346,20 +358,26 @@ read_header (FILE * infile, data_fmt * data, option_fmt * options)
         {
         case 'a':
             sscanf (input, "%ld%ld%[^\n]", &(data->numpop), &(data->loci),
-                    options->title);
-            find_delimiter (options->title, &data->dlm);
+                    title);
+            find_delimiter (title, &data->dlm);
+	if(!(title[0]==' ' || title[0] == '\0'))
+	  strcpy(options->title,title);
             break;
         case 'b':
         case 'm':
             sscanf (input, "%ld%ld%1s%[^\n]", &(data->numpop), &(data->loci),
-                    &(data->dlm), options->title);
+                    &(data->dlm), title);
+	    if(!(title[0]==' ' || title[0] == '\0'))
+	      strcpy(options->title,title);
             break;
         case 's':
         case 'n':
         case 'u':
         case 'f':
             sscanf (input, "%ld%ld%[^\n]", &(data->numpop), &(data->loci),
-                    options->title);
+                    title);
+	    if(!(title[0]==' ' || title[0] == '\0'))
+	      strcpy(options->title,title);
             break;
         default:
             usererror ("Datatype is wrong, please use a valid data type!");
