@@ -17,18 +17,21 @@
   
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
-$Id: definitions.h,v 1.96 2005/01/21 16:48:34 beerli Exp $
+$Id: definitions.h 178 2005-12-02 22:11:20Z beerli $
  
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "2.0.5"
+#define MIGRATEVERSION "2.1.0"
 #else
 #ifdef SGI
 #undef MIGRATEVERSION
-#define MIGRATEVERSION "2.0.5"
+#define MIGRATEVERSION "2.1.0"
 #endif
 #endif
+#ifndef MIGRATESUBVERSION
+#define MIGRATESUBVERSION "x"
+#endif
 
 #define MAINTAINER "Peter Beerli <beerli@csit.fsu.edu>"
 /*------------------------------------------------
@@ -73,7 +76,6 @@ $Id: definitions.h,v 1.96 2005/01/21 16:48:34 beerli Exp $
 #endif /*MWERKS*/
 
 #ifdef WIN32
-#define BAYESUPDATE
     #define DOS
     #undef HAVE_STRINGS_H
     #undef HAVE_LGAMMA
@@ -126,7 +128,15 @@ $Id: definitions.h,v 1.96 2005/01/21 16:48:34 beerli Exp $
 #define AICFILENUM 19
 #define BAYESFILE "bayesfile"
 #define BAYESFILENUM 20
+#define BAYESMDIMFILE "bayesallfile"
+#define BAYESMDIMFILENUM 22
+#define PDFOUTFILE "outfile.pdf"
+#define PDFOUTFILENUM 21
 #define BAYESNUMBIN 200
+#define PRETTY_MAX 0
+#define PRETTY_P99 1
+#define PRETTY_P99MAX 3
+#define PRETTY_P100 4
 #ifdef __STDIO_LOADED
 #define VMS
 #define MACHINE_TYPE "VAX/VMS C"
@@ -198,7 +208,8 @@ void vax_tweak_fmt (char *);
 
 //#include "sighandler.h"
 #define FClose(file) if (file) fclose(file) ; file=NULL
-typedef unsigned char boolean;
+typedef int boolean;
+//typedef unsigned char boolean;
 
 #ifndef TRUE
 #define TRUE    (boolean) 1
@@ -327,20 +338,24 @@ long chains is used */
 #define ATOF(a) strtod((a),(char **) NULL, 10)
 
 /* prior setting */
-#define ADAPTIVEPRIOR 3
-#define EXPPRIORB 2
+#define MULTPRIOR 3
+#define WEXPPRIOR 2
 #define EXPPRIOR 1
 #define UNIFORMPRIOR 0
 
 /* theta (4 Ne mu) related material */
+// ONLY good boundaries when used with DNA
 #define SMALLEST_THETA    1e-10
+#define DNA_GUESS_THETA    0.01
 #define BIGGEST_THETA      1e4
 #define SMALLEST_MIGRATION 1      /*m/mu equally likely*/
-#define BIGGEST_MIGRATION   10e9
+#define DNA_GUESS_MIG      100
+#define BIGGEST_MIGRATION   10e9 
 // defines the value that is used as a minimum summary statistic for migration events on all trees
 // version 1.2.4 had a value of 0.00000001, it seems that values of 0.1 are too large.
-// in version -1.6.9 this is set to zero, in 1.7 trial with 0.01 PB Dec 11 2002 
-#define MINMIGSUMSTAT 1.0
+// in version -1.6.9 this is set to zero, in 1.7 trial with 0.01 PB Dec 11 2002  [this was correct for Nm]
+// was set to 1 (M) for some time , but this might be biasing upwards, changing back to small value 
+#define MINMIGSUMSTAT 0.000001
 /* the migration limit is per population, should be plenty
    for moderate sample sizes */
 #define MIGRATION_LIMIT     5000
@@ -464,6 +479,9 @@ long chains is used */
 #define eventloop() /* eventloop would go here */
 #endif
 
+#ifdef powerpc
+#include <Accelerate/Accelerate.h>
+#endif
 
 #ifdef MEMDEBUG
 //#include <memdebug.h>
