@@ -8,18 +8,19 @@ using a Metropolis-Hastings Monte Carlo algorithm
  Peter Beerli 2001, Seattle
  beerli@csit.fsu.edu
  
- Copyright 2001-2002 Peter Beerli and Joseph Felsenstein
- 
+ Copyright 2001-2003 Peter Beerli and Joseph Felsenstein
+ Copyright 2004-2005 Peter Beerli
+
  This software is distributed free of charge for non-commercial use
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: gammalike.c,v 1.19 2004/08/28 19:59:31 beerli Exp $
+$Id: gammalike.c 175 2005-12-02 14:51:23Z beerli $
 */
 /*! \file gammalike.c 
 
 Calculates the gamma distributed rate variation among loci
-and derivatives
+and derivatives
 */
 
 
