@@ -18,7 +18,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c,v 1.73 2004/11/16 02:54:30 beerli Exp $
+$Id: mcmc1.c 175 2005-12-02 14:51:23Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc1.c
 
@@ -397,16 +397,30 @@ jumblenodes (node ** s, long n)
     free (temp);
 }
 
-
+///
+/// pick a node at random from the available list of nodes, this code will even 
+/// work with datasets where there are only two nodes.
 void
 chooseOrigin (proposal_fmt * proposal)
 {
     long elem = 0, oldelem = (proposal->sumtips * 2);
-    node *tmp, **goal;
+    node *tmp=NULL, **goal;
     goal = (node **) mycalloc (1, sizeof (node *) * oldelem);
     traverseAllNodes (crawlback (proposal->root->next), &goal, &elem, &oldelem,
                       NO_MIGR_NODES);
-    tmp = goal[RANDINT (0, elem - 2)];
+    switch(elem)
+      {
+      case 0:
+	error("problem with choosing a node for the tree change [choosOrigin()]");
+	break;
+      case 1:
+      case 2:
+	tmp = goal[0];
+	break;
+      default:
+	tmp = goal[RANDINT (0, elem - 2)];
+	break;
+      }
     proposal->origin = tmp;
     if (proposal->origin != showtop (crawlback (proposal->root->next)))
     {
@@ -748,7 +762,7 @@ migration_from_old (long to, proposal_fmt * proposal)
 {
     long j, ii, msta, msto;
     MYREAL *geo = proposal->world->data->geo;
-    MYREAL *r, rr = RANDUM ();
+    MYREAL *r, rr = UNIF_RANDUM ();
     r = (MYREAL *) mycalloc (1, sizeof (MYREAL) * proposal->numpop);
     msta = mstart (to, proposal->numpop);
     msto = mend (to, proposal->numpop);
@@ -774,7 +788,7 @@ migration_from (long to, proposal_fmt * proposal)
 {
     long ii = 0;
     MYREAL *r = proposal->world->migproblist[to];
-    MYREAL rr = RANDUM ();
+    MYREAL rr = UNIF_RANDUM ();
     while (rr > r[ii])
     {
         ii++;
@@ -940,11 +954,11 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
         if (pop1 == pop2)
         {
             denom = mm + (2. / proposal->param0[pop1]);
-            proposal->time = age1 - LOG (RANDUM ()) / denom;
+            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom;
             age1 = proposal->time;
             if (age1 < horizon)
             {
-                rr = RANDUM ();
+                rr = UNIF_RANDUM ();
                 r0 = (2. / proposal->param0[pop1]) / denom;
                 if (rr < r0)
                 {
@@ -955,7 +969,7 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
         else
         {
             denom = mm;
-            proposal->time = age1 - LOG (RANDUM ()) / denom;
+            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom;
             age1 = proposal->time;
         }
         if (age1 < horizon)
@@ -988,9 +1002,9 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
         if (pop1 == pop2)
         {
             denom = 2. * mm + (2. / proposal->param0[pop1]);
-            proposal->time = age1 - LOG (RANDUM ()) / denom;
+            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom;
             age1 = proposal->time;
-            rr = RANDUM ();
+            rr = UNIF_RANDUM ();
             r0 = ((2. / proposal->param0[pop1]) / denom);
             r1 = r0 + mm / denom;
             if (rr < r0)
@@ -1016,7 +1030,7 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
             //mm2 += proposal->param0[i];
             //}
             denom = mm + mm2;
-            proposal->time = age1 - LOG (RANDUM ()) / denom;
+            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom;
             age1 = proposal->time;
             if (RANDUM () < (mm / denom))
             {
@@ -1117,8 +1131,8 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
     node *first;
 #endif
 
-    boolean report = TRUE;
-    long oldg = -1;
+    //boolean report = TRUE;
+    //long oldg = -1;
     //MYREAL zz;
     MYREAL rr, expo;
     long rm;
@@ -1128,15 +1142,16 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
                 proposal->migr_table_counter + proposal->migr_table_counter2 +
                 world->migration_counts - rmc) > MIGRATION_LIMIT * world->numpop)
     {
-        if (report || g != oldg)
-        {
-            warning ("migration limit (%li) exceeded: %li\n",
-                     MIGRATION_LIMIT * world->numpop, rm);
-            warning
-            ("results may be underestimating migration rates for this chain\n");
-            report = FALSE;
-            oldg = g;
-        }
+// warning might disturb parallel runs and might be not really useful at all
+//        if (report || g != oldg)
+//        {
+//            warning ("migration limit (%li) exceeded: %li\n",
+//                     MIGRATION_LIMIT * world->numpop, rm);
+//            warning
+//            ("results may be underestimating migration rates for this chain\n");
+//            report = FALSE;
+//            oldg = g;
+//        }
         return FALSE;
     }
 #ifdef UEP
@@ -1199,17 +1214,19 @@ rmigrcount (proposal_fmt * proposal)
 MYREAL
 eventtime (proposal_fmt * proposal, long pop, vtlist * tentry, char *event)
 {
-    static boolean mig_force = TRUE;
+//    static boolean mig_force = TRUE;
     MYREAL interval, lines, denom;
     //MYREAL rate = proposal->world->options->mu_rates[proposal->world->locus];
     MYREAL mm = proposal->mig0list[pop];
     long design0 = proposal->design0list[pop];
     lines = 2.0 * tentry->lineages[pop];
     denom = mm + (lines / proposal->param0[pop]);
-    interval = (-(LOG (RANDUM ())) / denom); // * rate;
+    interval = (-(LOG (UNIF_RANDUM ())) / denom); // * rate;
+    if (interval < 0.0)
+        error("interval time is negative");
     if (lines > 0)
     {
-        if ((RANDUM ()) < (mm / denom))
+        if ((UNIF_RANDUM ()) < (mm / denom))
         {
             *event = 'm';
             return interval;
@@ -1226,14 +1243,12 @@ eventtime (proposal_fmt * proposal, long pop, vtlist * tentry, char *event)
                 {
                     if (RANDUM () < 0.1)
                     {
-                        if (mig_force)
-                        {
-                            warning ("Migration forced\n");
-                            warning
-                            ("results may be overestimating migration rates\n");
-                            warning ("for this chain\n");
-                            mig_force = FALSE;
-                        }
+// WARNING might disturb flow in distributed runs and also quite useless 
+                        //                        if (mig_force)
+//                        {
+//                            warning ("Migration forced\nresults may be overestimating migration rates\nfor this chain\n");
+//                            mig_force = FALSE;
+//                        }
                         *event = 'm';
                         return interval;
                     }
