@@ -17,7 +17,7 @@
   and is copyrighted. Of course, we do not guarantee that the software
   works and are not responsible for any damage you may cause or have.
 
-  $Id: menu.c,v 1.75 2005/01/21 16:48:35 beerli Exp $
+  $Id: menu.c 175 2005-12-02 14:51:23Z beerli $
 
   -------------------------------------------------------*/
 #include "migration.h"
@@ -105,7 +105,7 @@ enum dtep_menu {
 ///
 ///Enumeration of possible choices for Bayes menu
 enum bayesian_menu {
-  BAYESSTRATEGY, BAYESOUT, BAYESBINNING, BAYESFREQ, BAYESPRIOR, BAYESLCHAINS, BAYESSKIP, BAYESSAMPLES, BAYESBURNIN,
+  BAYESSTRATEGY, BAYESOUT, BAYESMDIMOUT, BAYESBINNING, BAYESPRETTY, BAYESFREQ, BAYESPRIOR, BAYESLCHAINS, BAYESSKIP, BAYESSAMPLES, BAYESBURNIN,
   BAYESREPLICATE, BAYESHEAT, BAYESMOVINGSTEPS
 };
 
@@ -253,7 +253,11 @@ print_menu_title(FILE * file, option_fmt * options)
     FPRINTF(file, "  ALTIVEC enabled\n");
 #endif
 
-    FPRINTF(file, "  Version %s\n", MIGRATEVERSION);
+    FPRINTF(file, "  Version %s ", MIGRATEVERSION);
+    if(strlen(MIGRATESUBVERSION)>0)
+      FPRINTF(file, "  [%s]\n", MIGRATESUBVERSION);
+    else
+      FPRINTF(file, "\n");
     get_time(nowstr, "  %c");
     if (nowstr[0] != '\0')
       FPRINTF(file, "  Program started at %s\n", nowstr);
@@ -295,7 +299,7 @@ print_title(world_fmt * world, option_fmt * options)
       len = (long) MAX(strlen(options->title), 45);
       for (i = 0; i < len; i++)
 	FPRINTF(world->outfile, "=");
-      FPRINTF(world->outfile, "\n  %s\n  ", options->title);
+      FPRINTF(world->outfile, "\n  %-*.*s\n  ", (int) len, (int) len,options->title);
     }
     for (i = 0; i < len; i++)
       FPRINTF(world->outfile, "=");
@@ -803,7 +807,7 @@ menuInput(option_fmt * options) {
   string4 = (char *) mymalloc(sizeof(char) * 128);
 
   do {
-    printf("  INPUT FORMATS\n  -------------\n");
+    printf("  INPUT FORMATS (for %s)\n  ------------- (change approach in SEARCH strategy)\n",options->bayes_infer ? "Bayesian approach" : "Maximum likelihood approach");
     printf("  %2i   Datafile name is %46.46s\n", MI_INFILE,
 	   options->infilename);
     switch (options->autoseed) {
@@ -826,12 +830,12 @@ menuInput(option_fmt * options) {
 	   MI_RAND, stringstep);
     printf("  %2i   Title of the analysis is", MI_TITLE);
 
-    if (len == 0 || (len == 5 && strstr(options->title, "AUTO ")))
+    if (len == 0 || (len == 5 && strstr(options->title, "AUTO")))
       printf("%39.39s\n", "<no title given>");
     else
       printf("%39.39s\n", options->title);
 
-    if (options->readsum) {
+    if (options->readsum && !options->bayes_infer) {
       printf("  %2i    Summary of genealogies are read from %s\n",
 	     MI_SUMREAD, options->sumfilename);
     }
@@ -846,101 +850,113 @@ menuInput(option_fmt * options) {
 
     printf("  %2i   Outputfile name is  %43.43s\n", MI_OUTFILE,
 	   options->outfilename);
+    printf("                           %43.43s\n", options->pdfoutfilename);
 
-    if (options->plot) {
-      switch (options->plotmethod) {
-      case PLOTALL:
-	strcpy(string2, "Yes, to outfile and mathfile");
+    if(!options->bayes_infer)
+      {
+	if (options->plot) 
+	  {
+	    switch (options->plotmethod) 
+	      {
+	      case PLOTALL:
+		strcpy(string2, "Yes, to outfile and mathfile");
+		break;
+	      default:
+		strcpy(string2, "Yes, to outfile");
+		break;
+	      }
+	  }
+	else 
+	  {
+	    strcpy(string2, "No");
+	  }
+	printf("  %2i   Plot likelihood surface? %38.38s\n",
+	       MI_PLOT, string2);
+	switch (options->profile) 
+	  {
+	  case NONE:
+	    strcpy(string3, "No");
+	    break;
+	  case ALL:
+	    strcpy(string3, "Yes, tables and summary");
+	    break;
+	  case TABLES:
+	    strcpy(string3, "Yes, tables");
+	    break;
+	  case SUMMARY:
+	    strcpy(string3, "Yes, summary");
+	    break;
+	  }
+	printf("  %2i   Profile-likelihood?%44.44s\n", MI_PROFILE, string3);
+	if (options->profile != NONE) 
+	  {
+	    switch (options->profilemethod) 
+	      {
+	      case 'p':
+		strcpy(string4, "[Percentiles using exact Bisection method]");
+		break;
+	      case 's':
+		strcpy(string4,
+		       "[Percentiles using not so exact Spline method]");
+		break;
+	      case 'd':
+		strcpy(string4,
+		       "[Evaluation at preset fractions of ML estimate]");
+		break;
+	      case 'q':
+		strcpy(string4, "[Assuming that parameter are independent]");
+		break;
+	      case 'f':
+		strcpy(string4, "[Mixture of 'p' and 'q']");
+		break;
+	      }
+	    printf("%70.70s\n", string4);
+	  }
+	printf("  %2i   Likelihood-Ratio tests?%40.40s\n",
+	       MI_LRT, options->lratio->counter > 0 ? " Yes" : "No");
+	
+	printf("  %2i   AIC model selection?   %40.40s\n",
+	       MI_AIC, options->aic ? (options->fast_aic ? "YES:Fast" : "Yes") : "No");
+      } /*if !bayes_infer*/
+
+    switch (options->treeprint) 
+      {
+      case ALL:
+	printf("  %2i   Print genealogies?     %40.40s\n",
+	       MI_TREES, treestr[1]);
 	break;
+      case BEST:
+	printf("  %2i   Print genealogies?     %40.40s\n",
+	       MI_TREES, treestr[2]);
+	break;
+      case LASTCHAIN:
+	printf("  %2i   Print genealogies?     %40.40s\n",
+	       MI_TREES, treestr[3]);
+	break;
+      case NONE:
       default:
-	strcpy(string2, "Yes, to outfile");
+	printf("  %2i   Print genealogies?     %40.40s\n",
+	       MI_TREES, treestr[0]);
 	break;
       }
-    } else {
-      strcpy(string2, "No");
-    }
-
-    printf("  %2i   Plot likelihood surface? %38.38s\n",
-	   MI_PLOT, string2);
-    switch (options->profile) {
-    case NONE:
-      strcpy(string3, "No");
-      break;
-    case ALL:
-      strcpy(string3, "Yes, tables and summary");
-      break;
-    case TABLES:
-      strcpy(string3, "Yes, tables");
-      break;
-    case SUMMARY:
-      strcpy(string3, "Yes, summary");
-      break;
-    }
-    printf("  %2i   Profile-likelihood?%44.44s\n", MI_PROFILE, string3);
-    if (options->profile != NONE) {
-      switch (options->profilemethod) {
-      case 'p':
-	strcpy(string4, "[Percentiles using exact Bisection method]");
-	break;
-      case 's':
-	strcpy(string4,
-	       "[Percentiles using not so exact Spline method]");
-	break;
-      case 'd':
-	strcpy(string4,
-	       "[Evaluation at preset fractions of ML estimate]");
-	break;
-      case 'q':
-	strcpy(string4, "[Assuming that parameter are independent]");
-	break;
-      case 'f':
-	strcpy(string4, "[Mixture of 'p' and 'q']");
-	break;
+    if(!options->bayes_infer)
+      {
+	printf("  %2i   Plot coordinates are saved in %33.33s\n",
+	       MI_PLOTCOORD, options->mathfilename);
+	if (options->writesum || options->datatype == 'g') 
+	  {
+	    if (!options->readsum && options->writesum) 
+	      {		
+		printf("  %2i   Summary of genealogies saved in %31.31s\n",
+		       MI_SUMFILE, options->sumfilename);
+	      }
+	  }
+	else 
+	  {
+	    printf("  %2i   Summary of genealogies  %39.39s\n",
+		   MI_SUMFILE, "will not be saved");
+	  }
       }
-      printf("%70.70s\n", string4);
-    }
-    printf("  %2i   Likelihood-Ratio tests?%40.40s\n",
-	   MI_LRT, options->lratio->counter > 0 ? " Yes" : "No");
-
-    printf("  %2i   AIC model selection?   %40.40s\n",
-	   MI_AIC, options->aic ? (options->fast_aic ? "YES:Fast" : "Yes") : "No");
-
-    switch (options->treeprint) {
-    case ALL:
-
-      printf("  %2i   Print genealogies?     %40.40s\n",
-	     MI_TREES, treestr[1]);
-      break;
-    case BEST:
-
-      printf("  %2i   Print genealogies?     %40.40s\n",
-	     MI_TREES, treestr[2]);
-      break;
-    case LASTCHAIN:
-
-      printf("  %2i   Print genealogies?     %40.40s\n",
-	     MI_TREES, treestr[3]);
-      break;
-    case NONE:
-    default:
-
-      printf("  %2i   Print genealogies?     %40.40s\n",
-	     MI_TREES, treestr[0]);
-      break;
-    }
-
-    printf("  %2i   Plot coordinates are saved in %33.33s\n",
-	   MI_PLOTCOORD, options->mathfilename);
-    if (options->writesum || options->datatype == 'g') {
-      if (!options->readsum && options->writesum) {
-
-	printf("  %2i   Summary of genealogies saved in %31.31s\n",
-	       MI_SUMFILE, options->sumfilename);
-      }
-    } else {
-      printf("  %2i   Summary of genealogies  %39.39s\n",
-	     MI_SUMFILE, "will not be saved");
-    }
     if (options->writelog)
       printf("  %2i   Save logging information into %33.33s\n", MI_LOGFILE,
 	     options->logfilename);
@@ -958,156 +974,168 @@ menuInput(option_fmt * options) {
     } else
       printf("  %2i   Read unique polymorphism? %20.20s\n", MI_UEPFILE, "NO");
 #endif
-    if (options->mighist) {
-      printf("  %2i   Show migration event statistics  %30.30s\n",
-	     MI_MIGHISTOGRAM, options->mighistfilename);
-    } else {
-      printf("  %2i   Show migration event statistics  %30.30s\n", MI_MIGHISTOGRAM, "No");
-    }
+
+    if (options->mighist) 
+      {
+	printf("  %2i   Show migration event statistics for %-10.10s %20.20s\n",
+	       MI_MIGHISTOGRAM, options->mighist_all ? "all events" : "mig events", options->mighistfilename);
+      } 
+    else 
+      {
+	printf("  %2i   Show migration event statistics  %30.30s\n", MI_MIGHISTOGRAM, "No");
+      }
     printf("\n\n  Are the settings correct?\n");
     printf
       ("  (type Y to go back to the main menu or the letter for the entry to change)\n");
     FGETS(input, LINESIZE, stdin);
     test = atoi(input);
-    switch (test) {
-    case MI_INFILE:
-      printf("  What is the datafile name?\n[Default: %s]\n", INFILE);
-      FGETS(input, LINESIZE, stdin);
-      if (input[0] == '\0')
-	strcpy(options->infilename, INFILE);
-      else {
-	strcpy(options->infilename, input);
-      }
-      break;
-    case MI_RAND:
-      do {
-	printf("  (A)utomatic or (S)eedfile or (O)wn\n");
-	printf("  Start value for Random-generator seed\n");
+    switch (test) 
+      {
+      case MI_INFILE:
+	printf("  What is the datafile name?\n[Default: %s]\n", INFILE);
 	FGETS(input, LINESIZE, stdin);
-	switch (uppercase(input[0])) {
-	case 'A':
-	  options->autoseed = AUTO;
+	if (input[0] == '\0')
+	  strcpy(options->infilename, INFILE);
+	else 
+	  {
+	    strcpy(options->infilename, input);
+	  }
+	break;
+      case MI_RAND:
+	do 
+	  {
+	    printf("  (A)utomatic or (S)eedfile or (O)wn\n");
+	    printf("  Start value for Random-generator seed\n");
+	    FGETS(input, LINESIZE, stdin);
+	    switch (uppercase(input[0])) 
+	      {
+	      case 'A':
+		options->autoseed = AUTO;
 #ifndef MAC
-
-	  timeseed = (unsigned long) time(NULL) / 4;
+		timeseed = (unsigned long) time(NULL) / 4;
 #else
-
-	  timeseed = (unsigned long) clock() / 4;
+		timeseed = (unsigned long) clock() / 4;
 #endif
-
-	  options->inseed = (long) timeseed + 1;
-	  break;
-	case 'S':
-	  get_filename(" What is the filename that contains the random number seed?", SEEDFILE, options->seedfilename);
-	  options->seedfile = fopen(options->seedfilename, "r");
-	  if (options->seedfile) {
-	    options->autoseed = NOAUTO;
-	    fscanf(options->seedfile, "%ld%*[^\n]",
-		   &options->inseed);
-	    fclose(options->seedfile);
-	  } else
-	    printf("\n\n  There is no seedfile present\n");
-	  break;
-	case 'O':
-	  options->autoseed = NOAUTOSELF;
-	  printf("  Random number seed (best values are x/4 +1)?\n");
-	  scanf("%ld%*[^\n]", &options->inseed);
-	  break;
-	}
-      }
-      while (options->autoseed < AUTO || options->autoseed > NOAUTOSELF);
-      break;
-    case MI_TITLE:
-      printf("  Enter a title? [max 80 Characters are used]\n");
-      FGETS(input, LINESIZE, stdin);
-      if (input[0] == '\0')
-	options->title[0] = '\0';
-      else
-	strncpy(options->title, input, 80);
-      break;
-    case MI_SUMREAD:
-      printf
-	(" What is the filename for the summary of genealogies\n[Default: %s]\n",
-	 SUMFILE);
-      FGETS(input, LINESIZE, stdin);
-      if (input[0] == '\0')
-	strcpy(options->sumfilename, SUMFILE);
-      else {
-	strcpy(options->sumfilename, input);
-      }
-      break;
-    case MI_PROGRESS:
-      printf("  Progress report during the run? <YES | Verbose | No>\n");
-      FGETS(input, LINESIZE, stdin);
-      switch (tolower(input[0])) {
-      case 'n':
-	options->progress = FALSE;
-	options->verbose = FALSE;
+		options->inseed = (long) timeseed + 1;
+		break;
+	      case 'S':
+		get_filename(" What is the filename that contains the random number seed?", SEEDFILE, options->seedfilename);
+		options->seedfile = fopen(options->seedfilename, "r");
+		if (options->seedfile) {
+		  options->autoseed = NOAUTO;
+		  fscanf(options->seedfile, "%ld%*[^\n]",
+			 &options->inseed);
+		  fclose(options->seedfile);
+		} else
+		  printf("\n\n  There is no seedfile present\n");
+		break;
+	      case 'O':
+		options->autoseed = NOAUTOSELF;
+		printf("  Random number seed (best values are x/4 +1)?\n");
+		scanf("%ld%*[^\n]", &options->inseed);
+		break;
+	      }
+	  }
+	while (options->autoseed < AUTO || options->autoseed > NOAUTOSELF);
 	break;
-      case 'v':
-	options->progress = TRUE;
-	options->verbose = TRUE;
-	break;
-      case '\0':
-      case 'y':
-      default:
-	options->progress = TRUE;
-	options->verbose = FALSE;
-	break;
-      }
-      input[0] = 'X';
-      break;
-    case MI_PRINTDATA:
-      options->printdata = !options->printdata;
-      break;
-    case MI_OUTFILE:
-      get_filename("  What is the output filename?", OUTFILE, options->outfilename);
-      break;
-    case MI_PLOT:
-      options->plot = !options->plot;
-      if (options->plot) {
-	get_plotoptions(options);
-	input[0] = '\0';
-      }
-      break;
-    case MI_PROFILE:
-      do {
-	printf("  Evaluate profile likelihoods:\n");
-	printf
-	  ("  (N)o, (A)all [Tables and Summary],\n  (T)ables, (S)ummary\n");
+      case MI_TITLE:
+	printf("  Enter a title? [max 80 Characters are used]\n");
 	FGETS(input, LINESIZE, stdin);
-      }
-      while (strchr("NATS", (int) uppercase(input[0])) == NULL);
-      switch (uppercase(input[0])) {
-      case 'N':
-	options->profile = NONE;
+	if (input[0] == '\0')
+	  options->title[0] = '\0';
+	else
+	  strncpy(options->title, input, 80);
 	break;
-      case 'A':
-	options->profile = ALL;
-	break;
-      case 'T':
-	options->profile = TABLES;
-	break;
-      case 'S':
-	options->profile = SUMMARY;
-	break;
-      }
-      if (options->profile != NONE) {
-	do {
-	  printf("  Method to evaluate the profiles?\n");
-	  printf("  (P)ercentiles: exact evaluation (slow)\n");
-	  printf
-	    ("  (F)ast       : Assuming parameters are indepenent\n                + one complete profile-maximization.\n");
-
-	  //printf
-	  // ("  (S)plines    : percentiles using splines\n                (fails sometimes)\n");
-	  printf
-	    ("  (D)iscrete   : evaluation at (0.02, 0.05, 0.1, .. , 50)*ML estimate\n");
-	  printf
-	    ("  (Q)uick      : Assuming parameters are indepenent\n");
-
-	  FGETS(input, LINESIZE, stdin);
+      case MI_SUMREAD:
+	printf
+	  (" What is the filename for the summary of genealogies\n[Default: %s]\n",
+	   SUMFILE);
+	FGETS(input, LINESIZE, stdin);
+	if (input[0] == '\0')
+	  strcpy(options->sumfilename, SUMFILE);
+	else {
+	  strcpy(options->sumfilename, input);
 	}
+	break;
+      case MI_PROGRESS:
+	printf("  Progress report during the run? <YES | Verbose | No>\n");
+	FGETS(input, LINESIZE, stdin);
+	switch (tolower(input[0])) {
+	case 'n':
+	  options->progress = FALSE;
+	  options->verbose = FALSE;
+	  break;
+	case 'v':
+	  options->progress = TRUE;
+	  options->verbose = TRUE;
+	  break;
+	case '\0':
+	case 'y':
+	default:
+	  options->progress = TRUE;
+	  options->verbose = FALSE;
+	  break;
+	}
+	input[0] = 'X';
+	break;
+      case MI_PRINTDATA:
+	options->printdata = !options->printdata;
+	break;
+      case MI_OUTFILE:
+	get_filename("  What is the output filename?", OUTFILE, options->outfilename);
+#ifdef PRETTY
+	strcpy(options->pdfoutfilename,options->outfilename);
+	strcat(options->pdfoutfilename,".pdf");
+#endif
+	break;
+      case MI_PLOT:
+	options->plot = !options->plot;
+	if (options->plot) 
+	  {
+	    get_plotoptions(options);
+	    input[0] = '\0';
+	  }
+	break;
+      case MI_PROFILE:
+	do 
+	  {
+	    printf("  Evaluate profile likelihoods:\n");
+	    printf
+	      ("  (N)o, (A)all [Tables and Summary],\n  (T)ables, (S)ummary\n");
+	    FGETS(input, LINESIZE, stdin);
+	  }
+	while (strchr("NATS", (int) uppercase(input[0])) == NULL);
+	switch (uppercase(input[0])) 
+	  {
+	  case 'N':
+	    options->profile = NONE;
+	    break;
+	  case 'A':
+	    options->profile = ALL;
+	    break;
+	  case 'T':
+	    options->profile = TABLES;
+	    break;
+	  case 'S':
+	    options->profile = SUMMARY;
+	    break;
+	  }
+	if (options->profile != NONE) 
+	  {
+	do 
+	  {
+	    printf("  Method to evaluate the profiles?\n");
+	    printf("  (P)ercentiles: exact evaluation (slow)\n");
+	    printf
+	      ("  (F)ast       : Assuming parameters are indepenent\n                + one complete profile-maximization.\n");	    
+	    //printf
+	    // ("  (S)plines    : percentiles using splines\n                (fails sometimes)\n");
+	    printf
+	      ("  (D)iscrete   : evaluation at (0.02, 0.05, 0.1, .. , 50)*ML estimate\n");
+	    printf
+	      ("  (Q)uick      : Assuming parameters are indepenent\n");
+	    FGETS(input, LINESIZE, stdin);
+	  }
 	while (strchr("pdqf", (int) lowercase(input[0])) == NULL);
 	switch (lowercase(input[0]))
 	  //in strchr removed s
@@ -1130,141 +1158,162 @@ menuInput(option_fmt * options) {
 	  default:
 	    options->profilemethod = 's';
 	    break;
-
 	  }
       }
-      set_profile_options(options);
-      break;
-    case MI_LRT:
-      if (options->lratio->counter > 0) {
-	options->lratio->counter = 0;
-      } else {
-	FPRINTF(stdout, "  Likelihood-Ratio tests:\n");
-	FPRINTF(stdout, "  -----------------------\n");
-	read_custom_menu_lratio(options);
-      }
-      break;
-    case MI_AIC:
-      printf
-	("  Use AIC to select minimal migration model?\n[Default: NO]\n");
-      FGETS(input, LINESIZE, stdin);
-      switch (uppercase(input[0])) {
-      case 'F':
-	options->fast_aic = TRUE;
-	options->aic = TRUE;
+	set_profile_options(options);
 	break;
-      case 'Y':
-	options->fast_aic = FALSE;
-	options->aic = TRUE;
+      case MI_LRT:
+	if (options->lratio->counter > 0) 
+	  {
+	    options->lratio->counter = 0;
+	  } 
+	else 
+	  {
+	    FPRINTF(stdout, "  Likelihood-Ratio tests:\n");
+	    FPRINTF(stdout, "  -----------------------\n");
+	    read_custom_menu_lratio(options);
+	  }
 	break;
-      case 'N':
-      default:
-	options->aic = FALSE;
-	options->fast_aic = FALSE;
-	break;
-      }
-      input[0] = 'x';
-      break;
-    case MI_TREES:
-      do {
-	printf("  Print genealogies:\n");
-	printf("  (N)one, (A)all [!], (B)est, (L)ast chain\n");
+      case MI_AIC:
+	printf
+	  ("  Use AIC to select minimal migration model?\n[Default: NO]\n");
 	FGETS(input, LINESIZE, stdin);
-      }
-      while (strchr("NABL", (int) uppercase(input[0])) == NULL);
-      switch (uppercase(input[0])) {
-      case 'N':
-	options->treeprint = NONE;
+	switch (uppercase(input[0])) 
+	  {
+	  case 'F':
+	    options->fast_aic = TRUE;
+	    options->aic = TRUE;
+	    break;
+	  case 'Y':
+	    options->fast_aic = FALSE;
+	    options->aic = TRUE;
+	    break;
+	  case 'N':
+	  default:
+	    options->aic = FALSE;
+	    options->fast_aic = FALSE;
+	    break;
+	  }
+	input[0] = 'x';
 	break;
-      case 'A':
-	options->treeprint = ALL;
+      case MI_TREES:
+	do 
+	  {
+	    printf("  Print genealogies:\n");
+	    printf("  (N)one, (A)all [!], (B)est, (L)ast chain\n");
+	    FGETS(input, LINESIZE, stdin);
+	  }
+	while (strchr("NABL", (int) uppercase(input[0])) == NULL);
+	switch (uppercase(input[0])) 
+	  {
+	  case 'N':
+	    options->treeprint = NONE;
+	    break;
+	  case 'A':
+	    options->treeprint = ALL;
+	    break;
+	  case 'B':
+	    options->treeprint = BEST;
+	    break;
+	  case 'L':
+	    options->treeprint = LASTCHAIN;
+	    break;
+	  default:
+	    options->treeprint = NONE;
+	    break;
+	  }
 	break;
-      case 'B':
-	options->treeprint = BEST;
+      case MI_SUMFILE:
+	printf(" Save genealogy summaries? [No]\n");
+	FGETS(input, LINESIZE, stdin);
+	if (uppercase(input[0]) == 'Y') 
+	  {
+	    options->writesum = TRUE;
+	    get_filename(" What is the filename for the summary of genealogies?", SUMFILE, options->sumfilename);
+	  } 
+	else 
+	  {
+	    options->writesum = FALSE;
+	  }
+	input[0] = 'X';
 	break;
-      case 'L':
-	options->treeprint = LASTCHAIN;
+      case MI_PLOTCOORD:
+	get_filename("  What is the plot coordinate filename?", MATHFILE, options->mathfilename);
 	break;
-      default:
-	options->treeprint = NONE;
+      case MI_LOGFILE:
+	printf(" Save logging information? [No]\n");
+	FGETS(input, LINESIZE, stdin);
+	if (uppercase(input[0]) == 'Y') 
+	  {
+	    options->writelog = TRUE;
+	    get_filename(" What is the filename for logging?", LOGFILE, options->logfilename);
+	  }
+	else 
+	  {
+	    options->writelog = FALSE;
+	  }
+	input[0] = 'X';
 	break;
-      }
-      break;
-    case MI_SUMFILE:
-      printf(" Save genealogy summaries? [No]\n");
-      FGETS(input, LINESIZE, stdin);
-      if (uppercase(input[0]) == 'Y') {
-	options->writesum = TRUE;
-	get_filename(" What is the filename for the summary of genealogies?", SUMFILE, options->sumfilename);
-      } else {
-	options->writesum = FALSE;
-      }
-      input[0] = 'X';
-      break;
-    case MI_PLOTCOORD:
-      get_filename("  What is the plot coordinate filename?", MATHFILE, options->mathfilename);
-      break;
-    case MI_LOGFILE:
-      printf(" Save logging information? [No]\n");
-      FGETS(input, LINESIZE, stdin);
-      if (uppercase(input[0]) == 'Y') {
-	options->writelog = TRUE;
-	get_filename(" What is the filename for logging?", LOGFILE, options->logfilename);
-      } else {
-	options->writelog = FALSE;
-      }
-      input[0] = 'X';
-      break;
 #ifdef UEP
-
-    case MI_UEPFILE:
-      printf(" UEP estimation? [No]\n");
-      FGETS(input, LINESIZE, stdin);
-      if (uppercase(input[0]) == 'Y') {
-	options->uep = TRUE;
-	get_filename(" What is the filename of the UEP data?", UEPFILE, options->uepfilename);
-      } else {
-	options->uep = FALSE;
-      }
+      case MI_UEPFILE:
+	printf(" UEP estimation? [No]\n");
+	FGETS(input, LINESIZE, stdin);
+	if (uppercase(input[0]) == 'Y') 
+	  {
+	    options->uep = TRUE;
+	    get_filename(" What is the filename of the UEP data?", UEPFILE, options->uepfilename);
+	  } 
+	else 
+	  {
+	    options->uep = FALSE;
+	  }
       input[0] = 'X';
       break;
-    case MI_UEPRATE:
-      do {
-	FPRINTF(stdout, "What is mutation rate for the UEP locus\n");
-	FPRINTF(stdout,
-		"[expressed as a ratio of the point mutation rate\n");
-	FPRINTF(stdout, "Reasonable values are 0.0 =< x <=1.0]\n");
-	FGETS(input, LINESIZE, stdin);
-	options->ueprate = atof(input);
-      }
+      case MI_UEPRATE:
+      do 
+	{
+	  FPRINTF(stdout, "What is mutation rate for the UEP locus\n");
+	  FPRINTF(stdout,
+		  "[expressed as a ratio of the point mutation rate\n");
+	  FPRINTF(stdout, "Reasonable values are 0.0 =< x <=1.0]\n");
+	  FGETS(input, LINESIZE, stdin);
+	  options->ueprate = atof(input);
+	}
       while (options->ueprate < 0.0);
       break;
-    case MI_UEPFREQ:
-      do {
-	FPRINTF(stdout, "What is the base frequency for the \"1\" allele\n");
-	FPRINTF(stdout, "Reasonable values are 0.0 < x <1.0]\n");
-	FGETS(input, LINESIZE, stdin);
-	options->uepfreq1 = atof(input);
-	options->uepfreq0 = 1. - options->uepfreq1;
-      }
+      case MI_UEPFREQ:
+      do 
+	{
+	  FPRINTF(stdout, "What is the base frequency for the \"1\" allele\n");
+	  FPRINTF(stdout, "Reasonable values are 0.0 < x <1.0]\n");
+	  FGETS(input, LINESIZE, stdin);
+	  options->uepfreq1 = atof(input);
+	  options->uepfreq0 = 1. - options->uepfreq1;
+	}
       while (options->uepfreq1 < 0.0);
       break;
 #endif
-    case MI_MIGHISTOGRAM:
-      printf(" Display migration event statistic and save events into file? [No]\n");
-      FGETS(input, LINESIZE, stdin);
-      if (uppercase(input[0]) == 'Y') {
-	options->mighist = TRUE;
-	get_filename(" What is the filename of the UEP data?", MIGHISTFILE, options->mighistfilename);
-      } else {
-	options->mighist = FALSE;
+      case MI_MIGHISTOGRAM:
+	printf(" Display migration event statistic and save events into file? [NO, ALL events, MIGration events]\n");
+	FGETS(input, LINESIZE, stdin);
+	if (uppercase(input[0]) == 'N') 
+	  {
+	    options->mighist = FALSE;
+	  } 
+	else 
+	  {
+	    options->mighist = TRUE;
+	    if (uppercase(input[0]) == 'A')
+	      options->mighist_all = TRUE;
+	    else
+	      options->mighist_all = FALSE;
+	    get_filename(" Specify a filename for the raw event data!", MIGHISTFILE, options->mighistfilename);
+	  }
+	input[0] = 'X';
+	break;
+      default:
+	break;
       }
-      input[0] = 'X';
-      break;
-
-    default:
-      break;
-    }
   }
   while (uppercase(input[0]) != 'Y');
   free(stringstep);
@@ -1591,23 +1640,18 @@ void            menuStrategy(option_fmt * options) {
   boolean         done = FALSE;
   do {
     printf("  SEARCH STRATEGY\n\n");
-#ifdef BAYESUPDATE
     if (!options->bayes_infer) {
-#endif
       display_standard_mcmc(options);
       print_bottom_menu_part();
       done = menuStrategy_standard(options);
-#ifdef BAYESUPDATE
     } else {
       display_adaptive_mcmc(options);
       print_bottom_menu_part();
       done = menuStrategy_bayes(options);
     }
-#endif				/* BAYESUPDATE */
   } while (done == FALSE);
 }
 
-#ifdef BAYESUPDATE
 ///
 ///reads menu choices and sets options accordingly
 boolean menuStrategy_bayes(option_fmt * options) {
@@ -1629,8 +1673,32 @@ boolean menuStrategy_bayes(option_fmt * options) {
     options->bayes_infer = !options->bayes_infer;
     break;
   case BAYESOUT:
-    get_filename("  What is the filename for the raw posterior distribution output?",
-		 BAYESFILE, options->bayesfilename);
+    printf(" Save posterior distribution (frequency histogram values)? [YES]\n");
+    FGETS(input, LINESIZE, stdin);
+    if (uppercase(input[0]) != 'N') 
+      {
+	options->has_bayesfile = TRUE;
+	get_filename("  What is the filename for the posterior distribution (frequency histogram)?",
+		     BAYESFILE, options->bayesfilename);
+      }
+    else
+      {
+	options->has_bayesfile = FALSE;
+      }
+    break;
+  case BAYESMDIMOUT:
+    printf(" Save posterior distribution (all raw parameter values)? [NO]\n");
+    FGETS(input, LINESIZE, stdin);
+    if (uppercase(input[0]) == 'Y') 
+      {
+	options->has_bayesmdimfile = TRUE;
+	get_filename("  What is the filename for the complete posterior distribution (raw parameter values)?",
+		     BAYESMDIMFILE, options->bayesmdimfilename);
+      }
+    else
+      {
+	options->has_bayesmdimfile = FALSE;
+      }
     break;
   case BAYESBINNING:
     do {
@@ -1644,46 +1712,77 @@ boolean menuStrategy_bayes(option_fmt * options) {
       count = sscanf(input, "%li%li", &options->bayespriortheta->bins, &options->bayespriorm->bins);
     } while (count != 2 && count > 0);
     break;
+  case BAYESPRETTY:
+    printf("Specify the method for plotting the posterior distribution!\n");
+    printf("Valid options are:\n");
+    printf("ALL     use the range of the prior distribution\n");
+    printf("P99     do not plot the values higher than the 99%% percentile for each parameter\n");
+    printf("MAXP99  plot up to the maximum 99%% percentile of all parameters.\n");
+    printf("TOTAL   plot up to the 100%% percentile of all parameters.\n");
+    printf("Current setting: %s\n",
+	   (options->bayespretty == PRETTY_P99 ? "P99" :
+	   (options->bayespretty == PRETTY_MAX ? "ALL" : 
+	   (options->bayespretty == PRETTY_P100 ? "TOTAL" : "MAXP99"))));
+    printf("\n\n==> ");
+    FGETS(input, LINESIZE, stdin);
+    switch(uppercase(input[0]))
+      {
+      case 'A':
+	options->bayespretty = PRETTY_MAX;
+	break;
+      case 'P':
+	options->bayespretty = PRETTY_P99;
+	break;
+      case 'T':
+	options->bayespretty = PRETTY_P100;
+	break;
+      case 'M':
+      default:
+	options->bayespretty = PRETTY_P99MAX;
+	break;
+      }
+    break;
   case BAYESFREQ:
     do {
-      printf("What is the frequency of the parameter updates vs the tree updates?\n[suggestion: 0.1, actual value: %f]\n", options->updateratio);
+      printf("What is the frequency of the parameter updates vs the tree updates?\n[suggestion for small problems: 0.5, actual value: %f]\n", options->updateratio);
       FGETS(input, LINESIZE, stdin);
       options->updateratio = atof(input);
     } while (options->updateratio > 1);
     break;
   case BAYESPRIOR:
     set_prior(priorstring, options->bayesprior);
-    printf("Specify the prior distribution\nand its parameters[Choices:\n (A)DAPTIVE EXPONENTIAL prior using window size delta\n (E)XPONENTIAL prior\n (W) EXPONENTIAL prior using window size delta\n (U)NIFORM prior\n [current=%s]\n",options->bayesprior==ADAPTIVEPRIOR ? "adaptive exp window" : options->bayesprior==EXPPRIOR ? "exponential" : options->bayesprior==EXPPRIORB ? "exp window" : "uniform");
+    printf("Specify the prior distribution\nand its parameters[Choices:\n (M)multiplier proposal\n (E)XPONENTIAL proposal\n (W) EXPONENTIAL proposal using window size delta\n (U)NIFORM prior\n [current=%s]\n",
+           options->bayesprior==MULTPRIOR ? "multiplier" : 
+           options->bayesprior==EXPPRIOR ? "exponential" : 
+           options->bayesprior==WEXPPRIOR ? "exp window" : "uniform");
     FGETS(input, LINESIZE, stdin);
     options->bayesprior = get_prior(input);
     switch (options->bayesprior) {
-    case ADAPTIVEPRIOR:
+    case MULTPRIOR:
       count = 0;
       do {
-	printf("Specify the MINIMUM, MEAN, MAXIMUM and DELTA-MULTIPLIER for THETA\n[Current setting: {%f %f %f %f}\n",
-	       options->bayespriortheta->min, options->bayespriortheta->mean, options->bayespriortheta->max, options->bayespriortheta->delta);
+	printf("Specify the MINIMUM, MAXIMUM and maximal MULTIPLIER for THETA\n[Current setting: {%f %f %f}\n",
+	       options->bayespriortheta->min, options->bayespriortheta->max, options->bayespriortheta->delta);
 	FGETS(input, LINESIZE, stdin);
 #ifdef USE_MYREAL_FLOAT
-	count = sscanf(input, "%f%f%f%f", &options->bayespriortheta->min, &options->bayespriortheta->mean,
+	count = sscanf(input, "%f%f%f", &options->bayespriortheta->min, 
 		       &options->bayespriortheta->max, &options->bayespriortheta->delta);
 #else
-	count = sscanf(input, "%lf%lf%lf%lf", &options->bayespriortheta->min, &options->bayespriortheta->mean,
+	count = sscanf(input, "%lf%lf%lf", &options->bayespriortheta->min, 
 		       &options->bayespriortheta->max, &options->bayespriortheta->delta);
 #endif
-      } while (count != 4 && count > 0);
+      } while (count != 3 && count > 0);
       count = 0;
       do {
-	printf("Specify the MINIMUM, MEAN, MAXIMUM and DELTA-MULTIPLIER for migration rate M\n[Current setting: {%f %f %f %f}\n",
-	       options->bayespriorm->min, options->bayespriorm->mean, options->bayespriorm->max, options->bayespriorm->delta);
+	printf("Specify the MINIMUM, MAXIMUM, and maximal MULTIPLIER for the migration rate M\n[Current setting: {%f %f %f}\n",
+	       options->bayespriorm->min, options->bayespriorm->max, options->bayespriorm->delta);
 	FGETS(input, LINESIZE, stdin);
 #ifdef USE_MYREAL_FLOAT
-	count = sscanf(input, "%f%f%f%f", &options->bayespriorm->min, &options->bayespriorm->mean,
-		       &options->bayespriorm->max, &options->bayespriorm->delta);
+	count = sscanf(input, "%f%f%f", &options->bayespriorm->min, &options->bayespriorm->max, &options->bayespriorm->delta);
 #else
-	count = sscanf(input, "%lf%lf%lf%lf", &options->bayespriorm->min, &options->bayespriorm->mean,
-		       &options->bayespriorm->max, &options->bayespriorm->delta);
+	count = sscanf(input, "%lf%lf%lf", &options->bayespriorm->min, &options->bayespriorm->max, &options->bayespriorm->delta);
 #endif
-      } while (count != 4 && count > 0);
+      } while (count != 3 && count > 0);
       break;
     case EXPPRIOR:
       count = 0;
@@ -1709,7 +1808,7 @@ boolean menuStrategy_bayes(option_fmt * options) {
 #endif
       } while (count != 3 && count > 0);
       break;
-    case EXPPRIORB:
+    case WEXPPRIOR:
       count = 0;
       do {
 	printf("Specify the MINIMUM, MEAN, MAXIMUM and DELTA for THETA\n[Current setting: {%f %f %f %f}\n",
@@ -1872,7 +1971,6 @@ boolean menuStrategy_bayes(option_fmt * options) {
   free(priorstring);
   return FALSE;
 }
-#endif				/* BAYESUPDATE */
 
 
 boolean         menuStrategy_standard(option_fmt * options) {
@@ -1885,12 +1983,10 @@ boolean         menuStrategy_standard(option_fmt * options) {
   
   //make changes to options
   switch          (atoi(input)) {
-#ifdef BAYESUPDATE
   case MLSTRATEGY://strategy change
     options->bayes_infer = !options->bayes_infer;
     input[0] = '\0';
     break;
-#endif				/* BAYESUPDATE */
   case MLSHORTCHAINS:
     do {
       printf("  How many Short Chains?\n");
@@ -2075,12 +2171,9 @@ void
 display_standard_mcmc(option_fmt * options) {
   char            temp[LINESIZE];
 
-#ifdef BAYESUPDATE
-
   printf("  0   Strategy: %42.42s\n", options->bayes_infer ?
 	 "Bayesian Inference" :
 	 "Maximum Likelihood");
-#endif
   printf("  1   Number of short chains to run?                %6ld\n",
 	 options->schains);
   if              (options->schains > 0) {
@@ -2147,7 +2240,6 @@ display_standard_mcmc(option_fmt * options) {
 	 options->gelman ? "Yes" : " No");
 }
 
-#ifdef BAYESUPDATE
 void
 display_adaptive_mcmc(option_fmt * options) {
   char           *outputstring;
@@ -2156,11 +2248,24 @@ display_adaptive_mcmc(option_fmt * options) {
   printf("  %2i   Strategy:%54.54s\n", BAYESSTRATEGY, options->bayes_infer ?
 	 "Bayesian Inference" :
 	 "Maximum Likelihood");
-  printf("  %2i   File for recording parameters?%33s\n",
-	 BAYESOUT, options->bayesfilename);
-  sprintf(outputstring, "%li, %li",
-	  options->bayespriortheta->bins, options->bayespriorm->bins);
+  //         "12345678901234567890123456789012345678901234567890123456789012345678901234567890"
+  //         "         1         2         3         4         5         6         7         8"
+  if(options->has_bayesfile)
+    sprintf(outputstring,"%s%s",  "YES:", options->bayesfilename);
+  else
+    sprintf(outputstring,"NO");
+  printf(  "  %2i   File for recording posterior distribution?%21s\n", BAYESOUT, outputstring);
+  if(options->has_bayesmdimfile)
+    sprintf(outputstring,"%s%s",  "YES:", options->bayesmdimfilename);
+  else
+    sprintf(outputstring,"NO");
+  printf(  "  %2i   File for recording all parameter values?  %21s\n", BAYESMDIMOUT, outputstring);
+  sprintf(outputstring, "%li, %li", options->bayespriortheta->bins, options->bayespriorm->bins);
   printf("  %2i   Number of bins of posterior [Theta,M]?%25s\n", BAYESBINNING, outputstring);
+  printf("  %2i   Plotting type of posterior distribution?%23s\n", BAYESPRETTY, 
+	 (options->bayespretty == PRETTY_P99 ? "up to 99% percentile" :
+	 (options->bayespretty == PRETTY_MAX ? "prior distr. range" :
+	 (options->bayespretty == PRETTY_P100 ? "up to ~100% percentile" : "up to maximal 99%"))));
   printf("  %2i   Frequency of tree updates vs. parameter updates?         %6.2f\n",
 	 BAYESFREQ, options->updateratio);
   set_prior(outputstring, options->bayesprior);
@@ -2191,7 +2296,6 @@ display_adaptive_mcmc(option_fmt * options) {
        BAYESHEAT, options->adaptiveheat ? "ADAPTIVE" : "STATIC", options->heated_chains);
   free(outputstring);
 }
-#endif				/* BAYESUPDATE */
 
 void
 display_lratio_menutext(void) {
@@ -2592,14 +2696,14 @@ start_data_method(option_fmt * options) {
 
 long            get_prior(char *input) {
   switch (toupper(input[0])) {
-  case 'A':
-    return ADAPTIVEPRIOR;
+  case 'M':
+    return MULTPRIOR;
     break;
   case 'E':
     return EXPPRIOR;
     break;
   case 'W':
-    return EXPPRIORB;
+    return WEXPPRIOR;
     break;
   case 'U':
     return UNIFORMPRIOR;
@@ -2611,18 +2715,18 @@ long            get_prior(char *input) {
 
 void            set_prior(char *output, long prior) {
   switch (prior) {
-  case ADAPTIVEPRIOR:
-    sprintf(output, "Adaptive exponential prior with multiplier");
+  case MULTPRIOR:
+    sprintf(output, "Multiplier proposal");
     break;
   case EXPPRIOR:
-    sprintf(output, "Exponential prior");
+    sprintf(output, "Exponential proposal");
     break;
-  case EXPPRIORB:
-    sprintf(output, "Exponential prior with window");
+  case WEXPPRIOR:
+    sprintf(output, "Exponential with window proposal");
     break;
   case UNIFORMPRIOR:
   default:
-    sprintf(output, "Uniform prior");
+    sprintf(output, "Uniform prior proposal");
     break;
   }
 }
