@@ -10,16 +10,20 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-  $Id: mig-histogram.c,v 1.10 2005/01/21 16:48:35 beerli Exp $
+  $Id: mig-histogram.c 175 2005-12-02 14:51:23Z beerli $
  
  */
 /*! \file mig-histogram.c
 Calculation and printing of migration event histogram
 */
 
+#include "tools.h"
 #include "mig-histogram.h"
 #include "sighandler.h"
 #include "migrate_mpi.h"
+#ifdef PRETTY
+#include "pretty.h"
+#endif
 
 void setup_mighist (world_fmt * world, option_fmt * options);
 void print_mighist (world_fmt * world);
@@ -105,8 +109,10 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL ***migtable,
 {
     long loc, p1;
     long loci1 = world->loci == 1 ? 1 : world->loci + 1;
-    FPRINTF (out, "\n\nSummary of Migration Events\n");
-    FPRINTF (out, "===============================\n\n");
+    FPRINTF (out, "\n\nSummary of %s events\n", 
+             world->options->mighist_all ? "coalescence and migration" : "migration");
+    FPRINTF (out, "===============%s================\n\n", 
+             world->options->mighist_all ? "=========================" : "=========");
     for (loc = 0; loc < world->loci; loc++)
         total[world->loci] += total[loc];
     for (loc = 0; loc < loci1; loc++)
@@ -123,14 +129,14 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL ***migtable,
         FPRINTF (out, "From    To   Average    Median     SE\n");
         FPRINTF (out,
                  "---------------------------------------------------------\n");
-        for (p1 = 0; p1 < world->numpop2; p1++)
+        for (p1 = (world->options->mighist_all ? 0 : world->numpop); p1 < world->numpop2; p1++)
         {
-            if (migtable[loc][p1][0] != migtable[loc][p1][1])
-            {
                 if (migtable[loc][p1][2] == NOAVERAGE)
+                {
                     FPRINTF (out, "%4li %4li    No migration event encountered\n",
                              (long) migtable[loc][p1][0] + 1,
                              (long) migtable[loc][p1][1] + 1);
+                }
                 else
                 {
                     FPRINTF (out,
@@ -141,7 +147,6 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL ***migtable,
                              migtable[loc][p1][4],
                              migtable[loc][p1][5] / total[loc]);
                 }
-            }
         }
         FPRINTF (out,
                  "---------------------------------------------------------\n");
@@ -160,7 +165,7 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL ***migtable,
 void
 print_mighist (world_fmt * world)
 {
-    long loc, i, z;
+    long loc, i;
     char plotype;
     char xlabel[255];
     char ylabel[255];
@@ -172,8 +177,11 @@ print_mighist (world_fmt * world)
     long from;
     FILE *out = world->outfile;
     long loci1 = world->loci == 1 ? 1 : world->loci + 1;
+    long numpop = world->numpop;
+    long numpop2 = world->numpop2;
     long *total;
     MYREAL ***migtable;
+    
     //loci x numpop2 x {mean, median, se}
 
     plotfield_fmt **plotfield;
@@ -188,11 +196,11 @@ print_mighist (world_fmt * world)
         for (loc = 0; loc < loci1; ++loc)
         {
             plotfield[loc] =
-                (plotfield_fmt *) mycalloc (world->numpop2, sizeof (plotfield_fmt));
+                (plotfield_fmt *) mycalloc (numpop2, sizeof (plotfield_fmt));
             migtable[loc] =
-                (MYREAL **) mycalloc (world->numpop2, sizeof (MYREAL *));
+                (MYREAL **) mycalloc (numpop2, sizeof (MYREAL *));
             histogram[loc] =
-                (histogram_fmt *) mycalloc (world->numpop2, sizeof (histogram_fmt));
+                (histogram_fmt *) mycalloc (numpop2, sizeof (histogram_fmt));
             for (i = 0; i < world->numpop2; ++i)
             {
                 histogram[loc][i].time = NULL;
@@ -213,16 +221,23 @@ print_mighist (world_fmt * world)
         strcpy (ylabel, "Count");
         for (loc = 0; loc < loci1; loc++)
         {
-            z = 0;
-            for (to = 0; to < world->numpop; ++to)
+            for (to = 0; to < numpop; ++to)
             {
-                for (from = 0; from < world->numpop; ++from)
+                if(world->options->mighist_all)
                 {
-                    sprintf (title, "Migrations from population %li to %li",
-                             from + 1, to + 1);
-                    setup_plotfield (&plotfield[loc][z], plotype, xsize, ysize,
-                                     xlabel, ylabel, yflabel, title, from != to);
-                    z++;
+                    sprintf (title, "Coalescences in population %li",
+                             to + 1);
+                    setup_plotfield (&plotfield[loc][mm2m(to,to,numpop)], plotype, xsize, ysize,
+                                     xlabel, ylabel, yflabel, title, TRUE);
+                }
+                for (from = 0; from < numpop; ++from)
+                {
+                    if(from!=to)
+                    {
+                        sprintf (title, "Migrations from population %li to %li",from + 1, to + 1);
+                        setup_plotfield (&plotfield[loc][mm2m(from,to,numpop)], plotype, xsize, ysize,
+                                         xlabel, ylabel, yflabel, title, TRUE);
+                    }
                 }
             }
         }
@@ -230,13 +245,17 @@ print_mighist (world_fmt * world)
         calc_mighistvalues (world, migtable, histogram, total);
         print_mighist_output (world->outfile, world, migtable, total);
 
-        print_histogram_ascii (out, histogram, plotfield, loci1, world->numpop2,
+        print_histogram_ascii (out, histogram, plotfield, loci1, numpop2,
                                NBINS, total, migtable);
+#ifdef PRETTY
+	pdf_print_mighist_table(world, migtable, total);
+        pdf_mig_histogram(histogram, plotfield, loci1, numpop2, NBINS, total, migtable, TRUE, world);
+#endif
         fflush (out);
         free (total);
         for (loc = 0; loc < loci1; loc++)
         {
-            for (i = 0; i < world->numpop2; ++i)
+            for (i = 0; i < numpop2; ++i)
             {
                 free (migtable[loc][i]);
                 free (plotfield[loc][i].data[0]);
@@ -284,7 +303,7 @@ long
 calc_migtable (MYREAL **migtable, histogram_fmt * histogram,
                mighistloci_fmt * aa, world_fmt * world, long loci)
 {
-    long p1, p2, pa, pb, i, j;
+    long p1, p2, pa, i, j;
     long maxloci, locus;
     long copies;
     long n, total = 0, maxsize;
@@ -355,35 +374,36 @@ calc_migtable (MYREAL **migtable, histogram_fmt * histogram,
     }
     for (p1 = 0; p1 < world->numpop; p1++)
     {
-        for (p2 = 0; p2 < p1; p2++)
+        if(world->options->mighist_all)
+        {            
+            migtable[p1][0] = p1;
+            migtable[p1][1] = p1;
+            migtable[p1][2] = average (migtime[p1][p1],
+                                       migcount[p1][p1],
+                                       gencount[p1][p1], &se, &n);
+            migtable[p1][4] = se;
+            migtable[p1][5] = n;
+            migtable[p1][3] = calc_quantile (migtime[p1][p1],
+                                             migcount[p1][p1],
+                                             gencount[p1][p1], 0.5);
+            prepare_hist (&histogram[p1], migtime[p1][p1], migcount[p1][p1],
+                          gencount[p1][p1]);
+        }
+        for (p2 = 0; p2 < world->numpop; p2++)
         {
-            pa = p2 * world->numpop + p1;
-            pb = p1 * world->numpop + p2;
+            pa = mm2m (p1, p2, world->numpop);
             migtable[pa][0] = p1;
-            migtable[pb][0] = p2;
             migtable[pa][1] = p2;
-            migtable[pb][1] = p1;
             migtable[pa][2] = average (migtime[p1][p2],
                                        migcount[p1][p2],
                                        gencount[p1][p2], &se, &n);
             migtable[pa][4] = se;
             migtable[pa][5] = n;
-            migtable[pb][2] = average (migtime[p2][p1],
-                                       migcount[p2][p1],
-                                       gencount[p2][p1], &se, &n);
-            migtable[pb][4] = se;
-            migtable[pb][5] = n;
             migtable[pa][3] = calc_quantile (migtime[p1][p2],
                                         migcount[p1][p2],
                                         gencount[p1][p2], 0.5);
-            migtable[pb][3] = calc_quantile (migtime[p2][p1],
-                                        migcount[p2][p1],
-                                        gencount[p2][p1], 0.5);
             prepare_hist (&histogram[pa], migtime[p1][p2], migcount[p1][p2],
                           gencount[p1][p2]);
-            prepare_hist (&histogram[pb], migtime[p2][p1], migcount[p2][p1],
-                          gencount[p2][p1]);
-
         }
     }
     for (p1 = 0; p1 < world->numpop2; p1++)
