@@ -10,9 +10,7 @@
 #include <stdarg.h>
 #include "migration.h"
 
-#ifdef BAYESUPDATE
 #include "bayes.h"
-#endif
 
 typedef struct _filedb_fmt {
 	FILE *file;
@@ -20,7 +18,7 @@ typedef struct _filedb_fmt {
 } filedb_fmt;
 
 
-extern filedb_fmt filedb[20];
+extern filedb_fmt filedb[30];
 extern long filenum;
 
 extern MPI_Comm comm_world;
@@ -92,7 +90,6 @@ extern long pack_mighist_buffer (char **buffer, world_fmt * world,
 extern void unpack_mighist_buffer (char *buffer, world_fmt * world,
                                        long locus, long maxrep, long numpop);
 
-#ifdef BAYESUPDATE
 extern void unpack_single_bayes_buffer(char *buffer,bayes_fmt * bayes, world_fmt * world,long locus);
 
 extern long pack_bayes_buffer (char **buffer, world_fmt * world,
@@ -100,7 +97,6 @@ extern long pack_bayes_buffer (char **buffer, world_fmt * world,
 
 extern void unpack_bayes_buffer (char *buffer, world_fmt * world,
                                  long locus, long maxrep, long numpop);
-#endif
 
 extern void mpi_gradient_master (nr_fmt * nr, world_fmt * world, int *who);
 
@@ -135,7 +131,9 @@ extern void mpi_profiles_worker (world_fmt * world, long *gmaxptr);
 extern void setup_parameter0_slowmpi (world_fmt * world, nr_fmt * nr, long repkind,
                                long repstart, long repstop, long loci,
                                long kind, boolean multilocus);
-extern long  mpi_send_stop_mcmc_worker(long numcpu, long loci, MPI_Comm *comm_workers, MPI_Request *irequests, MPI_Status *istatus, long id);
+extern long  mpi_send_stop_mcmc_lociworker(long numcpu, long loci);
+extern long  mpi_send_stop_mcmc_replicateworker(long numcpu, long loci);
+extern long  mpi_send_stop_mcmc_worker_orig(long numcpu, long loci, MPI_Comm *comm, MPI_Request *irequests, MPI_Status *istatus, long id);
 #endif /*slownet */
 
 extern int get_replicant_color(int numcpu, long maxreplicate, long loci);
