@@ -8,14 +8,15 @@
   using coalescent trees
  
   Peter Beerli
-  Genetics 357730
-  University of Washington
-  Seattle, WA 98195-7730, USA
+  School of Computational Science
+  Department of Biological Sciences
+  Florida State University
+  Tallahassee FL 32306-4120
   beerli@csit.fsu.edu
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id$
+  $Id: migration.h 175 2005-12-02 14:51:23Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -165,7 +166,6 @@ typedef struct _data
 }
 data_fmt;
 
-#ifdef BAYESUPDATE
 /// holds histogram and associated statistics for each locus
 typedef struct _bayeshistogram 
 {
@@ -217,9 +217,10 @@ typedef struct _bayes
   bayeshistogram_fmt *histogram;
   MYREAL *deltahist; // delta for all histograms per parameters [important for multilocus case 
   char * custm2; //pointer to the world->options->custm2;
+  long mdiminterval ; // interval at which the whole parameter list is printed to file
+  int prettyhist;
 }
 bayes_fmt;
-#endif
 
 /// storage for bayesian prior related parameters
 typedef struct prior_fmt
@@ -276,6 +277,7 @@ typedef struct _option
     boolean movingsteps;
     MYREAL acceptfreq;
     boolean printdata;
+  boolean printcov;
     boolean usertree;
     boolean usertreewithmig;
     boolean randomtree;
@@ -293,12 +295,14 @@ typedef struct _option
     MYREAL *plotyvalues;
     boolean simulation;
     boolean mighist;
+  boolean mighist_all;
     boolean mixplot;
     boolean dist;
     boolean geo;
     char *parmfilename;
     char *infilename;
     char *outfilename;
+  char *pdfoutfilename;
     char *logfilename;
     char *mathfilename;
     char *treefilename;
@@ -316,10 +320,9 @@ typedef struct _option
 
     char *uepfilename;
 #endif
-#ifdef BAYESUPDATE
 
     char *bayesfilename;
-#endif
+  char *bayesmdimfilename;
 
     char title[LINESIZE + 1];
     lratio_fmt *lratio;
@@ -374,12 +377,13 @@ typedef struct _option
     boolean bayes_infer;
     MYREAL updateratio;
     int bayesprior;
-#ifdef BAYESUPDATE
+  int bayespretty;
     prior_fmt *bayespriortheta;
     prior_fmt *bayespriorm;
     bayes_fmt *bayes;
-#endif
-
+  boolean has_bayesfile;
+  boolean has_bayesmdimfile;
+  long bayesmdiminterval;
     short thetaguess;
     short migrguess;
     boolean gamma;
@@ -690,6 +694,7 @@ typedef struct _worldoption
     MYREAL *probcat;
     long pluschain;
     boolean mighist;
+  boolean mighist_all;
     long burn_in;
     boolean usem;
     short migvar;
@@ -721,7 +726,10 @@ typedef struct _worldoption
 
     boolean fastlike;
     boolean bayes_infer;
-	MYREAL updateratio;
+  MYREAL updateratio;
+  boolean has_bayesfile;
+  boolean has_bayesmdimfile;
+  long bayesmdiminterval;
     MYREAL minmigsumstat;
 }
 worldoption_fmt;
@@ -878,13 +886,12 @@ typedef struct _world
     MYREAL accept_freq;
     long swapped;
     long G;
-#ifdef BAYESUPDATE
 	long bayesaccept;
     bayes_fmt *bayes;
     FILE *bayesfile;
-#endif
-
+  FILE *bayesmdimfile;
     FILE *outfile;
+  FILE *pdfoutfile;
     FILE *treefile;
     FILE *mathfile;
     FILE *mighistfile;
@@ -1095,11 +1102,10 @@ aic_struct;
 
 ///
 /// plot options
-/// \todo plotting options are incomplete, type=postscript is not coded yet
 typedef struct _plotfield_fmt
 {
     boolean print;
-    char type;   // 'a' = ascii plot, 'p' = postscript plot
+    char type;   // 'a' = ascii plot (see mig-histogram.c) , 'p' = PDF plotting (see pretty.c)
     long xsize;   // width  printpositions in chars
     long ysize;   // height printpositions in chars
     char xaxis[255];  //xaxis label
