@@ -17,12 +17,12 @@
    -----------------------------------------------------     
    part of the migrate                   
  
-   Copyright 1996-2002 Peter Beerli
+   Copyright 1996-2005 Peter Beerli
     This software is distributed free of charge for non-commercial use
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-   $Id: sighandler.c,v 1.26 2005/01/21 16:48:37 beerli Exp $                  
+   $Id: sighandler.c 175 2005-12-02 14:51:23Z beerli $                  
    ----------------------------------------------------- */
 /*! \file sighandler.c */
 #include "sighandler.h"
@@ -44,16 +44,18 @@ signalhandling (long switcher)
 {
     if (switcher == ON)
     {
+#ifndef WIN32
 #ifndef __MWERKS__
         signal (SIGIOT, signalhandler);
         signal (SIGTRAP, signalhandler);
         signal (SIGBUS, signalhandler);
-        signal (SIGUSR1, signalhandler);
+              signal (SIGUSR1, signalhandler);
 #ifndef SYSTEM_V
 
         signal (SIGXCPU, signalhandler);
         signal (SIGXFSZ, signalhandler);
 #endif
+#endif
 #endif
 
         signal (SIGFPE, signalhandler);
@@ -62,18 +64,19 @@ signalhandling (long switcher)
     }
     else
     {
+#ifndef WIN32
 #ifndef __MWERKS__
         signal (SIGIOT, SIG_DFL);
         signal (SIGTRAP, SIG_DFL);
         signal (SIGBUS, SIG_DFL);
-        signal (SIGUSR1, SIG_DFL);
+	      signal (SIGUSR1, SIG_DFL);
 #ifndef SYSTEM_V
 
         signal (SIGXCPU, SIG_DFL);
         signal (SIGXFSZ, SIG_DFL);
 #endif
 #endif
-
+#endif
         signal (SIGFPE, SIG_DFL);
         signal (SIGSEGV, SIG_DFL);
         signal (SIGILL, SIG_DFL);
@@ -88,145 +91,147 @@ signalhandler (int sig)
 
     switch (sig)
     {
+#ifndef WIN32
 #ifndef __MWERKS__
     case SIGIOT:
 #ifdef MPI
 
-        FPRINTF(stderr, "On node %i happened a", myID);
+        fprintf(stderr, "On node %i happened a", myID);
 #endif
 
-        FPRINTF (stderr, "\nSEVERE ERROR: Input/Output problem!\n");
-        FPRINTF (stderr,
+        fprintf (stderr, "\nSEVERE ERROR: Input/Output problem!\n");
+        fprintf (stderr,
                  "              Most likely a fatal error in the infile or parmfile\n\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              Please report error with as much detail as possible to\n");
-        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
+        fprintf (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     case SIGTRAP:
 #ifdef MPI
 
-        FPRINTF(stderr, "On node %i happened a", myID);
+        fprintf(stderr, "On node %i happened a", myID);
 #endif
 
-        FPRINTF (stderr, "SEVERE ERROR: Trace trap\n");
-        FPRINTF (stderr,
+        fprintf (stderr, "SEVERE ERROR: Trace trap\n");
+        fprintf (stderr,
                  "              there was an an overflow/underflow/0 divide problem\n");
-        FPRINTF (stderr, "              or some other problems.\n");
-        FPRINTF (stderr,
+        fprintf (stderr, "              or some other problems.\n");
+        fprintf (stderr,
                  "              But check your infile for errors, too.\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              Please report error with as much detail as possible to\n");
-        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
+        fprintf (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     case SIGBUS:
 #ifdef MPI
 
-        FPRINTF(stderr, "On node %i happened a", myID);
+        fprintf(stderr, "On node %i happened a", myID);
 #endif
 
-        FPRINTF (stderr, "SEVERE ERROR: Bus problems\n");
-        FPRINTF (stderr,
+        fprintf (stderr, "SEVERE ERROR: Bus problems\n");
+        fprintf (stderr,
                  "              this results in an non recoverable crash\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              But check your infile for errors, too.\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              Please report error with as much detail as possible to\n");
-        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
+        fprintf (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     case SIGXCPU:
 #ifdef MPI
 
-        FPRINTF(stderr, "On node %i happened a", myID);
+        fprintf(stderr, "On node %i happened a", myID);
 #endif
 
-        FPRINTF (stderr, "SEVERE ERROR: This program has a time limit?\n");
-        FPRINTF (stderr, "              We didn' program in a time limit,\n");
-        FPRINTF (stderr,
+        fprintf (stderr, "SEVERE ERROR: This program has a time limit?\n");
+        fprintf (stderr, "              We didn' program in a time limit,\n");
+        fprintf (stderr,
                  "              report this error to your system administrator, please.\n");
         exit (sig);
         break;
     case SIGXFSZ:
 #ifdef MPI
 
-        FPRINTF(stderr, "On node %i happened a", myID);
+        fprintf(stderr, "On node %i happened a", myID);
 #endif
 
-        FPRINTF (stderr, "SEVERE ERROR: This program has a file size limit?\n");
-        FPRINTF (stderr,
+        fprintf (stderr, "SEVERE ERROR: This program has a file size limit?\n");
+        fprintf (stderr,
                  "              We didn't program in a file size limit,\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              report this error to your system administrator, please.\n");
         exit (sig);
         break;
     case SIGUSR1:
 #ifdef MPI
-
-        FPRINTF(stderr, "On node %i happened a USER (?) SIGNAL\n", myID);
-        exit(sig);
+        fprintf(stderr, "On node %i happened a USER (%i) SIGNAL\n", myID, sig);
+	MPI_Finalize();
+	//	exit(sig);
 #endif
         //      warning ("\nUser signal received and ignored\n\n");
         break;
 
-#endif
-
+#endif /**__MWERKS__*/
+#endif /**WIN32*/
     case SIGFPE:
 #ifdef MPI
 
-        FPRINTF(stderr, "On node %i happened a", myID);
+        fprintf(stderr, "On node %i happened a", myID);
 #endif
 
-        FPRINTF (stderr, "SEVERE ERROR: Floating point exception\n");
-        FPRINTF (stderr,
+        fprintf (stderr, "SEVERE ERROR: Floating point exception\n");
+        fprintf (stderr,
                  "              There was an integer/floating point problem\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              Often this is a division by zero. If you dataset is moderately sized\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              this is most likely an error in you data (infile).\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              Please report error with as much detail as possible to\n");
-        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
+        fprintf (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     case SIGSEGV:
 #ifdef MPI
 
-        FPRINTF (stderr, "SEVERE ERROR: Segmentation fault on Node **%i**\n",
+        fprintf (stderr, "SEVERE ERROR: Segmentation fault on Node **%i**\n",
                  myID);
 #else
 
-        FPRINTF (stderr, "SEVERE ERROR: Segmentation fault\n");
+        fprintf (stderr, "SEVERE ERROR: Segmentation fault\n");
 #endif
 
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              this results in an non recoverable crash.\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              But check the datatype and your infile for errors, too.\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              Please report error with as much detail as possible to\n");
-        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
+        fprintf (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     case SIGILL:
 #ifdef MPI
 
-        FPRINTF(stderr, "On node %i happened a", myID);
+        fprintf(stderr, "On node %i happened a", myID);
 #endif
 
-        FPRINTF (stderr, "SEVERE ERROR: Illegal instruction!\n");
-        FPRINTF (stderr, "              this is maybe a programming error.\n");
-        FPRINTF (stderr,
+        fprintf (stderr, "SEVERE ERROR: Illegal instruction!\n");
+        fprintf (stderr, "              this is maybe a programming error.\n");
+        fprintf (stderr,
                  "              But check your infile for errors, too.\n");
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "              Please report error with as much detail as possible to\n");
-        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
+        fprintf (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     default:
         break;
     }
+#ifndef WIN32
 #ifndef __MWERKS__
     signal (SIGIOT, signalhandler);
     signal (SIGTRAP, signalhandler);
@@ -238,7 +243,7 @@ signalhandler (int sig)
     signal (SIGXFSZ, signalhandler);
 #endif
 #endif
-
+#endif
     signal (SIGFPE, signalhandler);
     signal (SIGSEGV, signalhandler);
     signal (SIGILL, signalhandler);
@@ -249,7 +254,8 @@ void
 warning (char string[], ...)
 {
     va_list args;
-    FPRINTF (stdout, "WARNING: ");
+    
+    fprintf (stdout, "WARNING: ");
     va_start (args, string);
     vfprintf (stdout, string, args);
     va_end (args);
@@ -259,7 +265,7 @@ void
 usererror (char string[], ...)
 {
     va_list args;
-    FPRINTF (stdout, "\nERROR: ");
+    fprintf (stdout, "\nERROR: ");
     va_start (args, string);
     vfprintf (stdout, string, args);
     va_end (args);
@@ -269,7 +275,7 @@ usererror (char string[], ...)
 void
 sig_error (char string[], char filename[], long line)
 {
-    FPRINTF (stdout, "\nIn file %s on line %li\n%s\n", filename, line, string);
+    fprintf (stdout, "\nIn file %s on line %li\n%s\n", filename, line, string);
     exit (-11);
 }
 
@@ -313,27 +319,27 @@ malloc_error_found (int value)
     switch (value)
     {
     case 0:
-        FPRINTF (stderr, "vm_allocate failed\n");
+        fprintf (stderr, "vm_allocate failed\n");
         break;
     case 1:
-        FPRINTF (stderr, "vm_deallocate failed\n");
+        fprintf (stderr, "vm_deallocate failed\n");
         break;
     case 2:
-        FPRINTF (stderr, "vm_copy failed\n");
+        fprintf (stderr, "vm_copy failed\n");
         break;
     case 3:
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "I tried to reallocate or free space which was already freed\n");
         break;
     case 4:
-        FPRINTF (stderr, "Internal memory verification in heap failed\n");
+        fprintf (stderr, "Internal memory verification in heap failed\n");
         break;
     case 5:
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "I tried to reallocate or free space which was never allocated\n");
         break;
     default:
-        FPRINTF (stderr, "huh, what mymalloc error was this?\n");
+        fprintf (stderr, "huh, what mymalloc error was this?\n");
         break;
     }
     errno = ENOMEM;
@@ -360,11 +366,11 @@ LAMARC_malloc (size_t size, const char file[], const long line)
     if (x == NULL)
     {
 #ifdef MPI
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "%i> ERROR in memory allocation (malloc(%li)) in file %s on line %li\n",
                  myID, size, file, line);
 #else
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "ERROR in memory allocation (malloc(%li)) in file %s on line %li\n",
                  size, file, line);
 #endif
@@ -386,11 +392,11 @@ LAMARC_calloc (size_t repeats, size_t size,
     if (x == NULL)
     {
 #ifdef MPI
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "%i> ERROR in memory allocation (calloc(%li,%li)) in file %s on line %li\n",
                  myID, repeats, size, file, line);
 #else
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "ERROR in memory allocation (calloc(%li,%li)) in file %s on line %li\n",
                  repeats, size, file, line);
 #endif
@@ -412,11 +418,11 @@ LAMARC_realloc (void *ptr, size_t size, const char file[],
     if (x == NULL)
     {
 #ifdef MPI
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "%i> ERROR in memory allocation (realloc(ptr,%li)) in file %s on line %li\n",
                  myID, size, file, line);
 #else
-        FPRINTF (stderr,
+        fprintf (stderr,
                  "ERROR in memory allocation (realloc(ptr,%li)) in file %s on line %li\n",
                   size, file, line);
 #endif
