@@ -20,7 +20,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c,v 1.73 2005/01/21 16:48:37 beerli Exp $
+$Id: tools.c 175 2005-12-02 14:51:23Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 #include "migration.h"
@@ -88,6 +88,7 @@ void translate (char *text, char from, char to);
 long count_words (char *text);
 void print_line (FILE * outfile, char c, long nn, long flag);
 void sprint_line (char *buffer, char c, long nn, long flag);
+void add_to_buffer(char *fp, long *bufsize, char **buffer);
 
 /* time reporting */
 void get_time (char *nowstr, char ts[]);
@@ -249,7 +250,7 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 #ifdef MPI
 	long i,j;
 #endif
-    long maxfilenum = 41; //20*2+1;
+    long maxfilenum = 43; //see definitions.h all files have a number and a filename;
 	tempdb = mycalloc(maxfilenum,sizeof(long));
 	
     if (myID == MASTER)
@@ -334,15 +335,19 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
         if (options->uep)
             openfile (&data->uepfile, options->uepfilename, "r+",  NULL);
 #endif
-#ifdef BAYESUPDATE
         if (options->bayes_infer)
-		  {
-            openfile (&world->bayesfile, options->bayesfilename, "w+",  NULL);
+	  {
+	    if(options->has_bayesfile)
+	      openfile (&world->bayesfile, options->bayesfilename, "w+",  NULL);
+	    if(options->has_bayesmdimfile)
+	      openfile (&world->bayesmdimfile, options->bayesmdimfilename, "w+",  NULL);
 #ifdef MPI
-            setup_filehandle_db((void *) world->bayesfile, world, options,data);
+	    if(options->has_bayesfile)
+	      setup_filehandle_db((void *) world->bayesfile, world, options,data);
+	    if(options->has_bayesmdimfile)
+	      setup_filehandle_db((void *) world->bayesmdimfile, world, options,data);
 #endif
 		  }			
-#endif /*BAYESUPDATE*/
 #ifdef MPI
 		tempdb[0]=filenum;
 		for(i=0, j=1;i<filenum;i++)
@@ -375,10 +380,13 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 			options->aicfile = filedb[j++].file;
 		if (options->plot && options->plotmethod == PLOTALL)
 			world->mathfile = filedb[j++].file;
-#ifdef BAYESUPDATE
         if (options->bayes_infer)
-			world->bayesfile = filedb[j++].file;
-#endif /*bayesupdate*/
+	  {
+	    if(options->has_bayesfile)
+	      world->bayesfile = filedb[j++].file;
+	    if(options->has_bayesmdimfile)
+	      world->bayesmdimfile = filedb[j++].file;
+	  }
 #endif /*MPI*/
 	  }
     free(tempdb);
@@ -424,12 +432,13 @@ exit_files (world_fmt * world, data_fmt * data, option_fmt * options)
         if (options->uep)
             FClose (data->uepfile);
 #endif
-#ifdef BAYESUPDATE
-
         if (options->bayes_infer)
-            FClose (world->bayesfile);
-#endif
-
+	  {
+	    if(options->has_bayesfile)
+	      FClose (world->bayesfile);
+	    if(options->has_bayesmdimfile)
+	      FClose (world->bayesmdimfile);
+	  }
     }
 }
 
@@ -2379,20 +2388,30 @@ mend (long pop, long numpop)
     return numpop + pop * numpop - pop + numpop - 1;
 }
 
-
+///
+/// return the first element of population pop
 long
 mmstart (long pop, long numpop)
 {
     return pop * (numpop);
 }
 
+
+///
+/// return the element past the last element in of population pop
 long
 mmend (long pop, long numpop)
 {
     return pop * numpop + numpop;
 }
 
-// returns the location in a full matrix given the abbreviated matrix
+/// 
+/// Returns the location in a full matrix given the abbreviated matrix
+/// given i,j coordinates in an abbreviated matrix {d,d,...,d,a,a,a,...,a,b,b,...,b, ...}
+/// it returns the position j* in a linearized full matrix with diagonal element "-"
+/// the linearized matrix would look like this {-, a,a,a,...,a, b, - , b,  .... ,b, c, c, -, c, ....},
+/// the position of i is the same for the abbreviated and the full matrix, and is not returned because
+/// the calling function knows this already.
 long
 mm2m (long frompop, long topop, long numpop)
 {
@@ -2404,7 +2423,12 @@ mm2m (long frompop, long topop, long numpop)
         return numpop + topop * (numpop - 1) + (frompop - 1);
 }
 
-// calulates the i and j from a linear abbrev matrix
+///
+/// Calulates the j and j from a linear abbreviated matrix
+/// position z in {d,d,d,...,d,a,a,...,a,b,b,...,b, c, ...} we know how many populations c (columns or rows) 
+/// exist and wnat to calculate the i,j coordinates in the c x c matrix {{d,a,a,...,a},{b,d,b,...},...}
+/// in the function z above is im and i = frompop, j is topop
+/// frompop and topop contain the result
 void
 m2mm (long i, long numpop, long *frompop, long *topop)
 {
@@ -2424,6 +2448,8 @@ m2mm (long i, long numpop, long *frompop, long *topop)
 }
 
 
+///
+/// position i in linear abbreviated array
 long
 m2mml (long i, long numpop)
 {
@@ -2620,7 +2646,7 @@ sgetc (char **buffer)
     return ch;
 }
 
-
+/// line-end transparent string gets command
 char *
 sgets (char *s, int size, char **stream)
 {
@@ -2647,6 +2673,16 @@ sgets (char *s, int size, char **stream)
 }
 
 
+/// sticks a text into the printing buffer
+void add_to_buffer(char *fp, long *bufsize, char **buffer)
+{
+	(*bufsize) += (long) strlen (fp) + 1;
+	(*buffer) = (char *) myrealloc (*buffer, (*bufsize) * sizeof (char));
+	strcat (*buffer, fp);
+}
+
+
+
 // calculates a rough approximation to log(val)
 // max error = 0.0007
 // Submitted by Laurent de Soras, posted on 30 March 2001
@@ -2692,7 +2728,7 @@ float fast_log (float vval)
 #define myEXPA 1512775.39519518569383584038231 
 #define myEXPC 60801 
 
-inline double fast_exp(double y) 
+MYINLINE double fast_exp(double y) 
 { 
     union 
     { 
